@@ -20,10 +20,9 @@ class Bot:
         self.group_id = group_id
         self.config = {}
         self.handlers = []
+        self.users_in_chain = []
         self.chains = []
         self.bound_chains = []
-        self.middlewares = []
-        self.is_rejected = False
 
     def handle(self, handler: Union[handlers.Handler]) -> handlers.Handler:
         self.handlers.append(handler)
@@ -67,10 +66,12 @@ class Bot:
         event_type = event["type"]
         event_params = get_event_params(event, event_type)
 
-        for chain in self.chains:
-            if not any([bound_chain.primal_chain == chain for bound_chain in self.bound_chains]):
+        if event_params["user_id"] not in self.users_in_chain:
+            for chain in self.chains:
                 if chain.is_trigger(event_params):
                     self.bound_chains.append(chain.bind_chain(event_params["user_id"]))
+                    self.users_in_chain.append(event_params["user_id"])
+                    break
 
         active_chains = [chain for chain in self.bound_chains if chain.is_trigger(event_type, event_params["user_id"])]
         tasks = [asyncio.create_task(chain.new_event(self.token, event, event_params))
@@ -80,6 +81,7 @@ class Bot:
             result = await future
             if not result[0]:
                 self.bound_chains.remove(result[1])
+                self.users_in_chain.remove(event_params["user_id"])
 
         active_handlers = [handler for handler in self.handlers if handler.is_trigger(event_params)]
         tasks = [asyncio.create_task(handler.new_event(self.token, event, event_params))
